@@ -1,6 +1,6 @@
 package Text::VisualPrintf;
 
-our $VERSION = "3.10";
+our $VERSION = "3.11";
 
 use v5.10;
 use strict;
@@ -17,7 +17,7 @@ sub vprintf  { &printf (@_) }
 sub vsprintf { &sprintf(@_) }
 
 use Text::VisualWidth::PP;
-our $IS_TARGET = qr/[\e\P{ASCII}]/;
+our $IS_TARGET = qr/[\e\b\P{ASCII}]/;
 our $VISUAL_WIDTH = \&Text::VisualWidth::PP::width;
 
 sub sprintf {
@@ -61,7 +61,7 @@ Text::VisualPrintf - printf family functions to handle Non-ASCII characters
 
 =head1 VERSION
 
-Version 3.10
+Version 3.11
 
 =head1 DESCRIPTION
 
